#

##

##

###

###

###

    	energy

    	summary
    		https://en.wikipedia.org/wiki/Units_of_energy

    	systems
    		system international

    			joule: 1 joule = kg * meters^2 * seconds^-2
    				# energy, work, heat

    				1 Joule = (1 kg) ("299,792,458 m/s" ^ 2)

    				E = (mass) ("speed of light" ^ 2)

    			watt:	1 watt = kg * meters^2 * seconds^-3
    				# power, radiant flux

    				capacity

    			volt:	1 volt = kg * m^2 * seconds^-3 * amperes^-1
    				# electrical potential, voltage, EMF

    			coulomb:
    				electrical charge

    			amp:
    				1 amp =	1 coulomb
    					  = 6.241509074 × 10^18 electrons' worth of charge

    		US customary
    			foot pound:
    				1 foot-pound force = 1.355818 joules
    								   = 0.0003240482791586998 food calories

    				1 food calorie =

    		food calories
    			calories:
    				# replaced by joules mostly

    				caloric theory of heat:
    					https://en.wikipedia.org/wiki/Calorie#Food_energy

    				{
    					large calorie,
    					food calorie,
    					dietary calories,
    					kilogram calorie,
    					kcal
    				}

    					originally defined as the amount of heat needed
    					to raise the temperature of one kilogram of
    					water by one degree celsius.

    					1 food calorie = 1 kcal
    					1 food calorie = 4184 joules
    					1 food calorie = 1000 small calories